| Title: | Data Extraction of Australian NBL Basketball Statistics |
|---|---|
| Description: | Allow users to obtain basketball statistics for the Australian basketball league 'NBL'<https://nbl.com.au/>. Stats include play-by-play, shooting locations, results and box scores for teams and players. |
| Authors: | Jason Zivkovic [aut, cre, cph] |
| Maintainer: | Jason Zivkovic <[email protected]> |
| License: | GPL-3 |
| Version: | 0.0.4 |
| Built: | 2026-05-10 09:40:23 UTC |
| Source: | https://github.com/jaseziv/nblr |
Returns a data frame of all available player box scores data for NBL matches played since 2015-16
nbl_box_player()nbl_box_player()
returns a dataframe of player box score data
try({ player_box <- nbl_box_player() })try({ player_box <- nbl_box_player() })
Returns a data frame of all available team box scores data for NBL matches played since 2015-16
nbl_box_team()nbl_box_team()
returns a dataframe of team box score data
try({ team_box <- nbl_box_team() })try({ team_box <- nbl_box_team() })
Returns a data frame of all available play-by-play data for NBL matches played since 2015-16
nbl_pbp()nbl_pbp()
returns a dataframe of play-by-play data
try({ pbp <- nbl_pbp() })try({ pbp <- nbl_pbp() })
Returns a data frame of all results in either wide or long form of all NBL matches played since 1979
nbl_results(wide_or_long)nbl_results(wide_or_long)
wide_or_long |
either 'wide' or 'long' to get either one row per match, or a row for each team for each match |
returns a dataframe of match results
try({ results_wide <- nbl_results(wide_or_long="wide") results_long <- nbl_results(wide_or_long="long") })try({ results_wide <- nbl_results(wide_or_long="wide") results_long <- nbl_results(wide_or_long="long") })
Returns a data frame of all available shot data for NBL matches played since 2015-16
nbl_shots()nbl_shots()
returns a dataframe of shot location data
try({ shots <- nbl_shots() })try({ shots <- nbl_shots() })